function [Rsr,Csr,Wsr,Rsri,Csri,THyx,CSIyx]=LPM_LUT(rr,cc,R,r0)
%LUT of the log-polar mapping
%[Rsr,Csr,Wsr,Rsri,Csri,THyx,CSIyx]=LPM_LUT(rr,cc,R,R0)
%Rsr: cartesian row indexes of the mapping
%Rsri: cartesian row coordinates of the mapping
%Csr: cartesian column indexes of the mapping
%Csri: cartesian column coordinates of the mapping
%Wsr: increase with eccentricity of the receptive field
%THyx/CSIyx: cortical coordinates of the inverse mapping
%rr,cc: number of rows and columns of the cartesian image
%R: number of rings (of the mapping) 
%r0: blind spot radius
%
%
% Authors:
% Fabio Solari and Manuela Chessa
% PSPC-lab - Biophysical and Electronic Engineering Department - University of Genoa
% March 2010



rr0=floor(rr/2); cc0=floor(cc/2);%center of the image
rho_max=min(rr0,cc0)-1;%outermost radius
rho_0=r0;%innermost radius
a=exp(log(rho_max/rho_0)/R);%logarithmic factor
S=round(2*pi/(a-1)); %number of sectors (spokes)

%LUT
Rsr=zeros(S,R);  Csr=zeros(S,R); Wsr=zeros(S,R);
Rsri=zeros(S,R);  Csri=zeros(S,R);
for si=1:S
    for ri=1:R
        Rsr(si,ri)=-round(rho_0*(a^ri)*sin(si*(2*pi/S))) + rr0;
        Csr(si,ri)=round(rho_0*(a^ri)*cos(si*(2*pi/S))) + cc0;
        Rsri(si,ri)=-(rho_0*(a^ri)*sin(si*(2*pi/S))) + rr0;
        Csri(si,ri)=(rho_0*(a^ri)*cos(si*(2*pi/S))) + cc0;
        Wsr(si,ri)=r0*((a-1)*a^(ri-1));
    end
end

%inverse LUT
THyx=zeros(rr,cc);CSIyx=zeros(rr,cc); 
for row=1:rr
    for col=1:cc
        THyx(row,col)=atan2(rr0-row,col-cc0);
        CSIyx(row,col)=0.5*log(((rr0-row)^2 + (col-cc0)^2)/rho_0^2)/log(a);
    end
end

maskth=THyx>=0;
THyx=THyx.*maskth + ~maskth.*(THyx+2*pi);
THyx=THyx*(S/(2*pi));


%%%
disp(sprintf('cartesian image: %dx%d pixel',rr,cc))
disp(sprintf('log-polar image: %dx%d sectorxring',S,R))
disp(sprintf('central blind spot:  %dx%d pixel',r0,r0))
disp(sprintf('cartesian/log-polar image size (compression ratio): %f',rr*cc/(S*R)))
disp(sprintf('min size of log-polar pixel: %fx%f cartesian pixel',(2*pi/S)*r0*a^0, r0*((a-1)*a^0) ))
disp(sprintf('max size of log-polar pixel: %fx%f cartesian pixel',(2*pi/S)*r0*a^(R-1), r0*((a-1)*a^(R-1)) ))
%%%



