function [W_ker,ind]=RF_sv(Wsr,R)
%Compute the space-variant receptive fields
%W_ker: space-variant kernels
%ind: index of 1:1 mapping
%Wsr: increase with eccentricity of the receptive field
%R: number of rings
%
%
% Authors:
% Fabio Solari and Manuela Chessa
% PSPC-lab - Biophysical and Electronic Engineering Department - University of Genoa
% March 2010

tmp=Wsr(1,:); tmp1=tmp>1;
ind = find(tmp1, 1) ; clear tmp1;
L=R-ind+1;
W_ker=cell(L,2);

for ii=1:L
    sig=tmp(ind+ii-1)/4;
    w=round(3*sig);
    [X,Y]=meshgrid(-w:w,-w:w);
    TMP=exp(-(X.^2)/(2*sig^2)-(Y.^2)/(2*sig^2));
    TMP=TMP>0.4;
    TMP=TMP/sum(sum(TMP));
    W_ker{ii,1}=TMP;
    W_ker{ii,2}=w;
end
    
